MercureAuth class sealed

Authentication strategy for Mercure hub requests.

The transport layer applies the chosen strategy to outgoing requests. Priority per spec: Authorization header > query param > cookie.

See https://mercure.rocks/spec#authorization

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited