type property
The event type (SSE event: field).
When null, the event is dispatched as a generic message event.
Implementation
final String? type;
The event type (SSE event: field).
When null, the event is dispatched as a generic message event.
final String? type;