QueryParam class final
Query parameter authentication.
The token is appended as ?authorization=<token> on the request URL.
This is the fallback for web subscribers that cannot use headers.
Not recommended due to token exposure in logs and browser history.
- Inheritance
-
- Object
- MercureAuth
- QueryParam
Constructors
- QueryParam(String token)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited