maxLineLength property
Maximum allowed line length in bytes. Lines exceeding this limit are discarded and an error is emitted. Defaults to 1 MB.
Implementation
final int maxLineLength;
Maximum allowed line length in bytes. Lines exceeding this limit are discarded and an error is emitted. Defaults to 1 MB.
final int maxLineLength;