maxEventSize property
Maximum allowed event size in bytes (accumulated data: fields).
Events exceeding this limit are discarded and an error is emitted.
Defaults to 10 MB.
Implementation
final int maxEventSize;
Maximum allowed event size in bytes (accumulated data: fields).
Events exceeding this limit are discarded and an error is emitted.
Defaults to 10 MB.
final int maxEventSize;