MercureEvent class final
A parsed Server-Sent Event received from a Mercure hub.
Constructors
- MercureEvent({String? id, String? type, required String data, int? retry})
-
const
Properties
- data → String
-
The event payload (SSE
data:field).final - hashCode → int
-
The hash code for this object.
no setteroverride
- id → String?
-
The event ID set by the hub (SSE
id:field).final - retry → int?
-
The reconnection delay hint in milliseconds (SSE
retry:field).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
The event type (SSE
event:field).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override