SubscriptionsResponse class final
The response from the Mercure Subscriptions API.
Wraps a list of SubscriptionInfo in a JSON-LD envelope. See https://mercure.rocks/spec#subscription
Constructors
-
SubscriptionsResponse({required String context, required String id, required String type, required String lastEventId, required List<
SubscriptionInfo> subscriptions}) -
const
-
SubscriptionsResponse.fromJson(Map<
String, dynamic> json) -
Parses a SubscriptionsResponse from a JSON-LD map.
factory
- SubscriptionsResponse.fromJsonString(String source)
-
Parses a SubscriptionsResponse from a JSON string.
factory
Properties
- context → String
-
The JSON-LD context (always
"https://mercure.rocks/").final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The collection IRI.
final
- lastEventId → String
-
The last event ID for this collection.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subscriptions
→ List<
SubscriptionInfo> -
The list of subscriptions.
final
- type → String
-
Always
"Subscriptions".final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited